@@ -3,7 +3,16 @@ import pandas as pd
 import plotly.graph_objects as go
 
 
-def draw_user_retention(df: pd.DataFrame) -> go.Figure:
+def draw_user_retention(
+    df: pd.DataFrame, width: int = 1550, height: int = 1550
+) -> go.Figure:
+    """
+    draw user retention heatmap
+    :params
+        df: user retention dataframe
+    :return
+        (go.Figure)
+    """
     z = df.values
     x = df.columns
     y = df.index
@@ -33,11 +42,12 @@ def draw_user_retention(df: pd.DataFrame) -> go.Figure:
             autorange="reversed",
         ),
         xaxis=dict(showgrid=False),
-        width=1550,
-        height=1550,
-        autosize=False,
+        width=width,
+        height=height,
+        autosize=True,
     )
     trace = go.Heatmap(x=x, y=y, z=z, colorscale="Peach")
     fig = go.Figure(data=trace, layout=layout)
     fig.update_layout(uniformtext_minsize=6, uniformtext_mode="hide")
+
     return fig
